#
# spec file for package golang-org-x-sys
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         golang
%global repo            sys
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     golang.org/x/sys

Name:           golang-org-x-%{repo}
Version:        0.0.0+git20200420.1957bb5
Release:        1.18
Summary:        Go packages for low-level interaction with the operating system
License:        BSD-3-Clause
Group:          Development/Languages/Golang
URL:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.xz
Source1:        rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  golang-packaging
BuildRequires:  xz

%{go_nostrip}
%{go_provides}

%description
This repository holds supplemental Go packages for low-level interactions with
the operating system.

%prep
%setup -q -n %{repo}-%{version}

%build
%goprep %{import_path}
%gobuild ...

%install
%goinstall
%gosrc
%gofilelist

%files -f file.lst
%license LICENSE
%{_bindir}/*
%doc README.md PATENTS AUTHORS CONTRIBUTORS CONTRIBUTING.md  

%changelog
* Mon Apr 27 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.0.0+git20200420.1957bb5:
  * unix: add SockaddrUnix tests on linux
  * Revert "unix: add openat2 for linux"
  * unix: update Dockerfile to Go 1.14.2
  * unix: fix name of generated zerrors_*.go in README
  * unix: add nexthop types and consts
  * unix: add openat2 for linux
  * unix: update Dockerfile to Linux 5.6, and Go 1.13.9
  * unix: add fs-verity consts and types
  * unix: allocate signalNameMap with enough space
  * unix: add readv/writev for illumos
  * gitignore: remove obsolete reference to .hgignore in comment
  * unix: regenerate all definitions on FreeBSD 12.1 on {386,amd64,arm64}
  * unix: add disk ioctl constants for FreeBSD
  * unix: only declare PtraceGetFsBase() on x86-based platforms
  * unix: implement L2TPIP socket address on Linux
  * unix: update BPF consts on linux
  * cpu: add mips64x feature detection
  * unix: merge duplicate code in ztypes_linux_*.go
  * unix: merge duplicate code in zsyscall_linux_*.go
  * unix: merge duplicate code in zerrors_linux_*.go
  * unix: add tool for merging duplicate code
  * unix: add adjtimex return constants
  * unix: mark capget/capset as non-blocking
  * unix: gofmt after CL 218799
  * unix: add RTMGRP_* consts from rtnetlink.h
  * unix: add InotifyInit for mips64
  * unix: update Dockerfile to Linux 5.5, glibc 2.31, Go 1.13.7
  * unix: use pipe2 syscall on OpenBSD
  * unix: add new setfsuid/setfsgid wrappers
  * unix: correct PtraceIoDesc and define PtraceIoDesc per GOARCH on freebsd
  * unix: test (*FdSet).Clear in TestFdSet
  * Revert "unix: fix Setfsuid and Setfsgid return values"
  * unix: fix Setfsuid and Setfsgid return values
  * cpu: don't read ARM64 registers on Android
  * windows: add missing network-related constants
  * unix: add missing chtmpdir in TestPpoll on openbsd
  * unix: add SysctlClockinfo on dragonfly and freebsd
  * unix: add Inet4Pktinfo type on solaris
  * unix: test UtimesNanoAt on *bsd and solaris
  * unix: don't zero out extra registers on riscv64 syscalls
  * unix: add flags argument in //sys comments for Fstatvfs1 and Statvfs1 on netbsd
  * unix: add Dup3 on netbsd and openbsd
  * unix: correct build tag to define Getdirentries for darwin/arm with Go 1.11
  * windows: added SO_RCVTIMEO and IPPROTO_ICMP constants
  * unix: compare Stat_t members in TestFstatat
  * unix: unify definition of func fcntl
  * unix: use correct file name in comment
  * unix: add Readv/Writev family of syscalls for linux
  * windows: fix recvfrom and sendto data types
  * unix: add PrctlRetInt, a Prctl variant that returns (int, error)
  * unix: move functions Ptrace{Get|Set}RegSetArm64 to a separate file
  * unix: replace readlink in mkall.sh with portable shell commands
  * unix: add functions PtraceGetRegSetArm64 and PtraceSetRegSetArm64
  * unix: add Statvfs and Fstatvfs on NetBSD
  * cpu: support reading arm64 CPU feature registers
  * windows: add Recvfrom and Sendto implementations
  * unix: add new fscrypt declarations from Linux v5.4
  * unix/linux: bump Linux and Go versions to latest stable releases
  * unix: check number of ready file descriptors in TestPselect
  * unix: don't fail TestSelect on EINTR from Select
  * windows: add Get*PreferredUILanguages
  * unix: use same TestSelect on all Unices
  * unix: fix EINTR check in TestPselect
  * unix: regenerate zerrors for AIX
  * windows: revert security_windows.go change of CL 202177
  * unix: don't fail TestPselect on EINTR from Pselect
  * unix: fix EINTR check in TestClockNanosleep
  * unix: don't fail TestClockNanosleep on EINTR from ClockNanosleep
  * unix: fix EpollEvent padding on mips64{,le}
  * unix: check correct CPU for being enabled in old mask in TestSchedSetaffinity
  * cpu: don't redeclare doinit on ppc64le
  * unix: accept time.Now()±1 as valid in TestTime
  * cpu: add basic support for GOARCH=riscv64
  * cpu: move empty doinit to own file
  * unix: skip TestPselect on EINTR
  * unix: test returned fd in TestEpoll
  * windows: add empty.s to fix build with Go 1.11 and earlier
  * unix: add TestEpoll on linux
  * unix: add methods to manipulate *FdSet
  * windows: add EnumProcesses function
  * windows/registry: make '-gcflags=all=-d=checkptr' flag work
  * unix: add devlink Linux generic netlink API constants
  * unix: add missing HCI_CHANNEL_LOGGING constant
  * windows/registry: remove TestWalkFullRegistry due to false assumptions
  * unix: don't use non-existing uint128 type on freebsd/arm64
  * windows/registry: allow for non-null terminated strings
  * unix: make convertFromDirents11 checkptr safe
  * unix: remove un-used ptrSize
  * unix: regenerate darwin libc trampolines after CL 202837
  * unix: __sysctl is sysctl on darwin
  * unix: comply with -d=checkptr in Test_anyToSockaddr
  * windows: respect permission bits on file opening
  * unix: don't use 32-bit aligned access for cmsgAlignOf on dragonfly after ABI change
  * windows, unix: fix wrong unsafe.Pointer alignment in syscall
  * unix: avoid "just past the end" pointers in UnixRights
  * windows: add GetDiskFreeSpaceEx function
  * unix: update rtnetlink constants
  * unix: add new func PtraceInterrupt on Linux
  * windows: fix ShellExecute return condition
  * windows: use go:linkname instead of assembly
  * windows: add module handle functions
  * unix: add new func PtraceSeize on Linux
  * unix: add Klogset and related SYSLOG_ACTION_ constants
  * windows/mkwinsyscall: import mksyscall_windows.go from go repo
  * windows/svc: use CloseServiceHandle for service handles
  * unix: avoid __getdirentries64 on darwin
  * unix: update openbsd/{386,amd64.arm} MAP_* consts
  * windows: add LockFileEx, UnlockFileEx system calls
  * cpu: support ARM feature detection on Linux
  * windows: revert breaking API changes from CL 196798, add new accessor funcs
  * unix: add NFDBITS const on Linux, update TestSelect
  * unix: fix Select to return number of ready fds on Solaris
  * unix: re-generate Select on dragonfly
  * windows: use pseudo handle constants to implement GetCurrentProcess
  * unix: fix Select to return number of ready fds on Darwin and *BSD
  * windows: make SID.String() conform to the String interface
  * windows: do not return invalid error for psuedo-handle functions
  * windows: use correct type for security attributes' descriptor member
  * windows: support SECURITY_DESCRIPTOR and ACL for secured objects
  * unix: add KEYCTL_RESTRICT_KEYRING capabilities
  * windows: do not corrupt stack with larger boolean return value
  * unix: redefine TIPC_WAIT_FOREVER as a uint32 value
  * windows: add various functions for shutting down and logging out
  * unix: update Dockerfile to Linux 5.3 and use ubuntu 19.04 base image
  * unix: add IfaCacheinfo on linux
  * unix: sort Linux-specific includes in linux/types.go and mkerrors.sh
  * cpu: remove encoding/binary dependency
  * unix: add Msghdr.SetIovlen for solaris/amd64
  * unix: add Msghdr.SetIovlen
  * unix: disable sysctl on iOS
  * cpu: add a space before build tag comment
  * unix: implement AF_TIPC sockets on Linux
  * unix/linux: upgrade Docker build container to Go 1.13
  * unix: add IoctlRetInt for Linux
  * unix: fix coredump bit on aix/ppc64
  * windows: open process tokens with duplicate access
  * unix: unify Ioctl* functions
  * windows: add mutex management functions
  * unix: use bits.OnesCount64 instead of local copy
  * windows: add Windows directory accessors
  * windows: allow re-enabling priority boost
  * windows: allow retrieving true version with RtlGetNtVersionNumbers
  * unix/linux: update Dockerfile to glibc 2.30
  * unix: disable ptrace on iOS
  * unix: fix epoll_event padding on riscv64
  * windows: add support for automatic delayed start in windows service
  * unix: remove nacl build tag from dirent code
  * unix: fix several staticcheck issues
  * windows: add CTRL_CLOSE_EVENT, CTRL_LOGOFF_EVENT, and CTRL_SHUTDOWN_EVENT
  * unix: add riscv64 tag to endian_little.go
  * unix: add constants and types to work with Linux loop devices
  * unix: update Dockerfile to Linux 5.2 and Go 1.13beta1
  * unix: add missing dirent* helper functions on aix
  * unix: don't use syscall.ParseDirent
  * unix: add Getdents on dragonfly
  * unix: use ParseDirent in testGetdirentries
  * unix: fix nil pointer dereference in Getdirentries on 32-bit freebsd 12
  * unix: add missing import in readdirent_getdirentries.go
  * unix: fix Getdirentries emulation using Getdents on netbsd, openbsd
  * unix: add test for Getdirentries
  * unix: merge implementation for ReadDirent
  * unix: add support to get/set Linux capabilities
  * unix: correctly rename Val member in Sigset_t on freebsd
  * unix: add ptrace support for FreeBSD
  * unix: add AT_SYMLINK_FOLLOW const on openbsd
  * unix: add AT_SYMLINK_FOLLOW const on netbsd
  * windows: make CoTaskMemFree public
  * unix: remove net dependency
  * windows: allow determining real version number
  * unix: fix Getdirentries emulation using Getdents on netbsd, openbsd
  * unix: change the mksysnum master to point to stable/11 on freebsd
  * windows: rename some arguments to follow MSDN
  * windows: allow looking up well-known folder paths
  * windows: add OpenThread function
  * windows: add GetProcessId function
  * unix: fix Getdirentries on 32-bit freebsd 12
  * windows: expose GetCurrentProcessId function
  * windows: allow determining if manager is locked
  * windows: correct types and error values of internal GUID handling
  * windows: add Thread32{First,Next} funcions
  * windows: properly plumb sidtype into service creation
  * windows: add GUID handling functions
  * windows: add accessor for duration since boot
  * windows: add constants for access rights
  * windows: make it easier to iterate over groups and privileges
  * windows: delete mkerrors.go
  * unix: provide linux/riscv64 assembly for syscalls
  * unix: fix TestFchmodat on illumos
  * Revert "windows: make zsyscall_windows.go generatable on non-WSL env"
  * windows: make zsyscall_windows.go generatable on non-WSL env
  * windows: add GenerateConsoleCtrlEvent function
  * plan9: modify mkall.sh to support zsyscall*.go files generation
  * cpu: add missing linkname for libc_getsystemcfg on aix/ppc64
  * windows: add SetInformationJobObject functions
  * windows: add functions for priority class
  * cpu: don't depend on the golang.org/x/sys/unix package for AIX
  * unix: fix Signalfd function signature on linux
  * windows: add ResumeThread function
  * windows: allow Windows-style printf debugging via MessageBox
  * windows: add ShellExecute
  * windows: allow determining if running 32-on-64bit
  * windows: add SID getter functions for the various components
  * windows: add SetErrorMode function
  * windows: add IP() accessor to SocketAddress type
  * windows: add JobObject functions
  * unix: add MCAST_* constants on linux
  * unix: add RawSockaddrDatalink on aix
  * windows: do not query library for inline functions
  * windows: add missing service constants
  * windows/registry: do not generate unaligned loads
  * unix: remove unused stringsFromByteSlice for tests on aix
  * unix: remove StTimespec type on AIX
  * windows: add functions for dealing with elevated tokens
  * windows: add token group adjustment function
  * unix: fix TestStatFieldNames on aix and TestUtimesNanoAt on darwin
  * unix: rename Stat_t time fields to [AMCB]tim
  * windows: add token environment functions
  * windows: add basic WTS functions for windows/svc usage
  * windows: add service notification support
  * windows: add token manipulation functions and constants
  * windows: add "generate" build tag
  * unix: add IoctlGetUint32 on Linux
  * unix: add BPF constants on Linux
  * unix: export KexecFileLoad on linux/arm
  * unix: update Dockerfile to Linux 5.1
  * windows: CreateFile's templatefile parameter has always been a HANDLE
  * unix: add missing tpacket block (sub)header
  * unix: add illumos case
  * unix: support generating netbsd/arm64 files in mkall.sh
  * unix: drop reference to mkunix.pl from comment
  * windows: don't return EINVAL on zero Chmod mode
  * windows: document new ProcessId field
  * unix: replace "mksysctl_openbsd.pl" script with a Go program
  * unix: skip TestOpenByHandleAt if name_to_handle_at not supported
  * windows: allow querying service ProcessId
  * unix: add FileHandle, NewFileHandle, NameToHandleAt, OpenByHandleAt
  * unix: add Linux crypto configuration API constants and types
  * unix: add support for openbsd/arm64
  * unix: remove arch specific build for openbsd_pledge.go
  * unix: add unexported name_to_handle_at and open_by_handle_at types & wrappers
  * unix: add Unmount syscall for AIX
  * unix: add Select syscall on AIX
  * unix: use nsendmsg and nrecvmsg on AIX
  * unix: fix cmsg alignment on aix
  * unix: move helper handler before AIX handler in TestPassFD
  * unix: enable TestPassFD on AIX 7.2 TL >= 2
  * windows: add GetFileInformationByHandleEx function
  * windows: add missing error constants
  * unix: add missing rtnetlink IFLA_* constants on Linux
  * unix: add missing rtnetlink neighbor constants on Linux
  * unix: add missing rtnetlink IFA_* constants on Linux
  * unix: allow empty string argument to SetsockoptString
  * unix: don't generate raw syscall wrapper for ClockGettime on darwin
  * unix: remove ClockGettime for darwin/amd64 on Go 1.11
  * unix: add SysctlClockinfo on darwin
  * unix: add GetsockoptUint64 and SetsockoptUint64
  * windows: add GetOverlappedResult function for async I/O
  * windows: add missing file flags to types
  * unix: add SysctlClockinfo on OpenBSD
  * windows: add support for creating well known SIDs
  * cpu: use unix.Getsystemcfg to detect POWER8/POWER9 on aix/ppc64
  * unix: run mkasm independent of mktypes in mkall.sh
  * unix: add Getsystemcfg on aix
  * windows: use proper system directory path in fallback loader
  * unix, unix/linux: add additional Linux perf API bits
  * cpu: add build tag to cpu_wasm.go
  * unix: add SetsockoptPacketMreq on Linux
  * all: add go directive to go.mod
  * cpu: define cacheLineSize and doinit for WASM
  * windows/svc: safely load system DLLs
  * unix: add functions to get/set tpacket socket options
  * unix: on ARM GNU/Linux let Pipe fall back to pipe
  * unix: add Lutimes
  * unix: update Dockerfile to Go 1.12 and Linux 5.0
  * unix: add fanotify API on Linux
  * unix: add SignalNum to convert signal name to a number
  * windows/svc: align ctlHandler parameters
  * windows/svc: add Context to ChangeRequest
  * unix: use 64-bit alignment on netbsd-arm
  * cpu: add CPU features for s390x
  * cpu: don't panic on error reading /proc/self/auxv
  * all: add a go.mod file
  * unix: don't overwrite unrelated file descriptors in TestDup
  * unix: add type NdUseroptmsg on Linux
  * unix: add SetsockoptCanRawFilter for linux
  * unix: add SetsockoptSockFprog on Linux for attaching BPF filters
  * cpu: fix build for GOARCH=ppc64{,le} on GOOS!=linux
  * windows: gofmt -w windows/security_windows.go
  * unix: do not invoke Mkfifo with a relative path in a read-only directory
  * cpu: unexport HWCap and HWCap2
  * cpu: fix auxval parsing on big-endian systems
  * cpu: fix build for GOARCH=arm64 on GOOS!=linux
  * unix: replace Perl script references in "README.md" with Go programs
  * unix: replace "mksyscall_solaris.pl" script with a Go program
  * unix: add ClockGettime on darwin/amd64
  * unix: update zsysnum_darwin_amd64 for macOS 10.14
  * unix: require GOOS be set in mksyscall
  * unix/linux: update Dockerfile to glibc 2.29 and Go 1.12beta2
  * windows: Implement WaitForMultipleObjects
  * unix: set 100644 mode on mksyscall_aix_ppc64.go
  * unix: add RND* ioctl consts on Linux
  * cpu: detect RDRAND and RDSEED instructions on x86
  * unix: add ioctl wrappers to get and set RTC time on Linux
  * unix: fix misspellings
  * unix: regenerate sysnum files for freebsd/arm64 and netbsd/arm64
  * unix: use glibc release branch in Dockerfile
  * unix: replace "mksyscall_aix_ppc64.pl" script with a Go program
  * unix: add socket error queue constants and types from linux/errqueue.h
  * unix: add netbsd/arm64 files.
  * unix: use int8 for RawSockaddrUnix.Path on linux/riscv64
  * unix: use Renameat2 to implement Renameat on linux/riscv64
  * unix: add Renameat on dragonfly
  * unix: add Signalfd on linux
  * unix: add ClockNanosleep and TIMER_ABSTIME
  * unix: get *BSD syscalls.master files using HTTPS
  * unix: replace "mksyscall_aix_ppc.pl" script with a Go program
  * cpu: add linux/ppc64x
  * plan9: replace "mksyscall.pl" with Go program
  * unix: make Fcntl* routines use libSystem on Darwin
  * plan9: remove "use" function and calls from generated code.
  * unix/linux: update Dockerfile to Linux Kernel 4.20
  * unix: add support for freebsd/arm64
  * unix: fix Fstatat by using fillStat_t on linux/mips64x
  * unix: mksysnum: correct +build restriction
  * unix: replace mksysnum_*.pl scripts with Go program
  * unix: generate linux/sparc64 go files using Docker
  * unix: fix unused import in syscall_darwin_386.go
  * unix: add space to generated code
  * unix: reverse default for 1.11/1.12 split
  * unix: add Sendfile test
  * unix/linux: set 100644 mode on mksysnum.go
  * unix: remove raw syscall from Sendfile
  * unix: remove raw syscall from getAttrList
  * unix: remove raw syscall from getattrlistTimes
  * unix: remove raw syscall from Getfsstat
  * unix: remove Getdirentries on iOS
  * unix: avoid "64"-postfixed libSystem calls on iOS
  * unix: convert Darwin syscalls from raw to libSystem
  * unix: update Dockerfile to Go 1.12beta1
  * windows/svc: use wevtutil.exe instead of powershell for windows/arm
  * windows: use netevent.dll in TestFormatMessage for windows/arm
  * unix: remove Flock syscall for aix
  * unix: add SyncFileRange on linux/arm
  * unix: evaluate cmsg alignment in cmsgAlignOf at compile time
  * unix: use correct cmsg alignment for openbsd/arm
  * unix: regenerate ztypes for openbsd/arm
  * unix: always use fstatat(AT_SYMLINK_NOFOLLOW) over lstat on AMD64
  * unix: always use inotify_init1 over inotify_init on AMD64
  * unix: avoid index out of range in Vmsplice with empty iovs
  * cpu: add linux/arm64
  * unix/linux: replace "mksysnum.pl" script with a Go program
  * unix: replace "mksyscall.pl" script with a Go program
  * unix: rework TestGetwd to handle test dirs whose names contain symlinks
  * unix: add IoctlSetPointerInt
  * unix: add ioctl definitions for PPP interfaces.
  * unix: add sockaddr and defines for PPPoE sockets.
  * unix: export FdSet bits field on freebsd
  * unix: add IoctlGetPtmget on netbsd
  * unix: test UtimesNanoAt on darwin
  * unix: don't use deprecated sys/capability.h header on FreeBSD
  * unix: fix errors in syscalls when using -linkshared on ppc64x
  * unix: avoid index out of range in *setxattr on BSD
  * unix: add remaining *at functions on dragonfly
  * unix: add remaining *at functions on netbsd
  * unix: add remaining *at functions on openbsd
  * unix: add Readlinkat on openbsd
  * unix: add Openat on dragonfly
  * unix: add Openat on netbsd
  * unix: allow to pass a NULL pointer to the pledge syscall
  * unix: add kernel module load/unload syscalls on Linux
  * unix: add support for OpenBSD unveil(2)
  * unix: use ppoll to implement Pause on linux/{arm64,riscv64}
  * unix: add Openat on openbsd
  * unix: add Ppoll on openbsd
  * unix: update Dockerfile to Linux 4.19
  * unix: don't use local syscall number in Pledge()
  * unix: FreeBSD 12 ino64 support
  * unix: update syscall numbers to OpenBSD 6.4
  * unix: add SOF_TIMESTAMPING_* flags on Linux
  * unix: add support for aix/ppc64, gc implementation
  * unix: add marker comments to zsyscall_solaris_amd64.go
  * unix: convert errorList and signalList to new format for linux/sparc64
  * unix: add KexecFileLoad on linux/{amd64,ppc64x,s390x}
  * unix: export sizeof consts
  * unix: use correctly aligned result buffer in SysctlClockinfo
  * unix: add SysctlUvmexp on OpenBSD
  * unix: re-add vm.* sysctl strings on openbsd/amd64
  * unix: add NCSI generic netlink constants
  * unix: add ClockGetres on Linux
  * unix: add SysctlClockinfo on NetBSD
  * unix: fix TestSchedSetaffinity for smt settings
  * unix: add additional rlimit resource constants on NetBSD
  * unix: add MNT_* flags on OpenBSD
  * windows: add support for windows/arm
  * unix: add MNT_* flags on DragonflyBSD
  * unix: add MNT_* flags on NetBSD
  * unix: implement Linux AF_XDP sockets
  * unix: add more RTA_* constants on Linux
  * unix: add Termio, Winsize, Statfs_t, TC[GS]ET, Mkdir and Mknod for AIX
  * unix: change MemfdCreate flags parameter to int for all GOARCHes
  * unix: add MemfdCreate on Linux
  * unix: correct misspelling in test output
  * windows: correct misspelling in comment
  * unix: add remaining RTA_* constants for use with rtnetlink on Linux
  * unix: add support for linux/riscv64
  * unix: add SYNC_FILE_RANGE_* constants on Linux
  * unix: correct argument order for SyncFileRange syscall on linux/ppc64{,le}
  * Revert "unix: implement SyncFileRange for ARM"
  * unix: implement SyncFileRange for ARM
  * windows: add support for AF_UNIX sockets
  * unix: update Dockerfile to Go 1.11
  * unix: code for AIX ppc and ppc64, for gccgo
  * unix: add UBI ioctl constants on Linux
  * unix: use pipe2 syscall on FreeBSD instead of pipe
  * unix: add additional file mode bit constants from sys/stat.h on Solaris
  * unix: add example for Flock
  * unix: add NOSTD syscall numbers on FreeBSD
  * unix: add additional file mode bit constants from sys/stat.h on FreeBSD
  * unix: add additional file mode bit constants from sys/stat.h on DragonflyBSD
  * windows: add Wincrypt.h Cert related values
  * unix: update Dockerfile to Linux 4.18, glibc 2.28 and Go 1.11beta3
  * unix: update the OpenBSD pledge interface to handle execpromises
  * unix: add *xattr functions on NetBSD
  * unix: add additional file mode bit constants from sys/stat.h on OpenBSD
  * unix: add F*xattr on Darwin
  * unix: drop incorrect Fsetxattr size return value
  * unix: add S_IRWXG and S_IRWXO to FreeBSD types
  * unix: add F*xattr on Linux
  * unix: add IFLA_INFO_KIND on Linux
  * unix: remove *xattr from list of unimplemented syscalls on FreeBSD
  * unix: add Renameat2 on Linux
  * unix: fix OpenBSD codegen to include F_OK
  * unix, windows: add type aliases to std syscall for Signal, Errno, SysProcAttr
  * unix: add Linux network namespace constants
  * unix: support Faccessat flags argument
  * unix: add Linux blkpg_ioctl_arg and blkpg_partition types
  * x/sys: improve NewCallback documentation
  * unix: implement pipe() on linux/mips
  * unix: document IoctlSetWinsize and IoctlSetTermios and fix pointer lifetime
  * windows/svc/mgr: add ability to set a reboot message and command when a service fails
  * unix: implement RFCOMM sockets on Linux
  * unix: update Dockerfile to Go 1.11beta1
  * windows: add missing file attributes
  * unix: regenerate syscall wrappers for linux/ppc64{,le}
  * windows, windows/svc/mgr: add ability to modify service recovery settings.
  * unix: do not return non-nil error for 0 errno in FcntlInt
  * unix: fix TestUtimesNanoAt for filesystems with 1-second resolution time stamps
  * unix: don't check atime in TestUtimesNanoAt
  * unix: use private copy of ustat_t on Linux
  * unix: check faccessat flags parameter on Linux
  * unix: don't use deprecated syscalls on linux/arm64
  * unix: add Faccessat on Solaris
  * windows: replace uintptr in crypto structs
  * windows: follow convention for generated code comment
  * plan9: follow convention for generated code comment
  * unix: follow convention for generated code comment
  * unix: add rtc defines and types
  * unix: add Faccessat on NetBSD
  * unix: add Faccessat on OpenBSD
  * unix: update Dockerfile to Ubuntu 18.04, Linux 4.17, and Go 1.10.3
  * windows: update TOKEN_ALL_ACCESS according to WinNT.h
  * unix: support compiling with gccgo on linux/386
  * unix: drop use function stub for gccgo
  * cpu: fix gccgo build
  * cpu: add gccgo implementation
  * cpu: introduce and export type CacheLinePad
  * unix: don't check atime in TestStatx
  * unix: make Nfgenmsg a type definition
  * unix: add nftables defines and types
  * unix: fix TestXattr on android
  * unix: fix or skip failing tests on android and iOS
  * unix: delete TestDevices for *BSD and Darwin
  * windows: add QueryServiceStatusEx function
  * unix: add symlink-safe *xattr functions on darwin
  * unix: skip TestStatx if the operation is not permitted
  * unix: delete TestDevices test for Solaris
  * unix: add tests for *xattr functions
  * windows: address error reported by vet
  * unix: add {get,set,remove,list}xattr on darwin
  * unix: update openbsd/amd64 to OpenBSD 6.3
  * unix: exclude AUDIT_RECORD_MAGIC constant on darwin
  * unix: add tpacket types and constants on Linux
  * unix: fix TestSCMCredentials to not fail when root
  * unix: add statfs and filesystem magic constants on Linux
  * windows: address vet reports
  * unix: address vet's finding of  wrong argument size
  * cpu: use t.Fatal instead of t.Fatalf
  * unix: add ErrnoName and SignalName
  * windows/svc: correct MOVL instruction in sys_amd64.s
  * cpu: new package
  * unix: use Fstatat for Stat on linux/amd64
  * unix: use pselect on amd64 to satisfy Android
  * unix: 32-bit MIPS splice system call returns int, not int64
  * unix: add Linux block device ioctl types and constants
  * unix: avoid extra syscall on send/recvmsg on Linux
  * unix: fix typos in linux/types.go.
  * unix: add tcp_md5sig on Linux
  * unix: re-export Fsid and Sigset_t Val member on Linux
  * unix: implement getrtable/setrtable syscalls on OpenBSD
  * unix: add wrapper around perf_event_open on Linux
  * unix: don't export any padding/alignment fields on all platforms
  * unix: add a step to mkall.go that generates ABI headers to be referenced from types.go
  * unix: update Dockerfile to Linux 4.16 and Go 1.10.1
  * unix: add FcntlInt
  * unix: unify Getsockopt*
  * unix: solicit EPERM via wrong PID in creds test.
  * unix: add CRTSCTS on netbsd and openbsd
  * unix: add sendfile support on Solaris
  * unix: add GetsockoptLinger and GetsockoptTimeval
  * unix: use strings.IndexByte instead of for loops
  * unix: don't export padding fields on Darwin
  * unix: add Fadvise on linux/{arm64,mipsx.mips64x,ppx64x,sparc64}
  * unix: add Fadvise on NetBSD
  * unix: fix TestFchmodat on Illumos
  * unix: enable TestFchmodat for all Unices
  * unix: add Fchmodat on NetBSD
  * unix: add Fchmodat on DragonflyBSD
  * unix: add Fchmodat on OpenBSD
  * unix: fix example
  * plan9, unix, windows: add paragraph breaks in docs
  * unix: add Exec call
  * unix: add IFLA attributes on linux/sparc64
  * unix: add Fstatat on Darwin
  * unix: add Fstatat on OpenBSD
  * CONTRIBUTING.md: remove note about not accepting Pull Requests
  * unix: add Fstatat on NetBSD
  * unix: add Fstatat on FreeBSD
  * unix: don't export padding fields on DragonflyBSD
  * unix: add Fstatat on DragonflyBSD
  * unix: don't export padding fields on Solaris
  * unix: add Fstatat on Solaris
  * unix: extend rlimit test on Linux
  * unix: fix seek while compiling with gccgo under arm and 386
  * plan9: use bytes.IndexByte instead of a for loop
  * unix: use bytes.IndexByte instead of a for loop
  * unix: skip SchedAffinity test on single CPU system
  * unix: fix nil pointer dereference in Select on linux/{arm64,mips64x}
  * windows/registry: improve ReadSubKeyNames permissions
  * unix: add IFLA_* constants for Linux 4.15
  * unix: update to Linux 4.15, glibc 2.27 and Go 1.10
- Install mkwinsyscall into %%{_bindir}
- Move LICENSE from %%doc to %%license section
* Wed Feb  7 2018 boris@steki.net
- Update to version 0.0.0+git20180202.37707fd:
  * unix: move gccgo redeclared *SyscallNoError functions to a separate file
  * unix: fix cpuset size argument in sched_affinity syscall
  * unix: use SyscallNoError and RawSyscallNoError on Linux only
  * unix: fix godoc comment for clen
  * unix: add godoc for Sockaddr* types
  * plan9: add arm support
  * unix: add sockaddr_l2 definitions
  * unix: don't export padding fields on all platforms
  * unix: use ParseDirent from syscall
  * unix: adjust replacement regex for removed struct fields for linux/s390x
- added CONTRIBUTING.md to package documentation
* Tue Dec 13 2016 tboerger@suse.com
- Update to version 0.0.0+git20161205.478fcf5:
  * x/sys/unix: add *linkat functions on linux
  * unix: Fix *linkat on sparc64 and s390x
  * unix: Add FADV_* constants for linux/arm
  * unix: fix name of prlimit parameters
  * x/sys/unix: add Getsid on linux
  * x/sys/unix: added SockaddrCAN struct to allow creation of AF_CAN sockets
  * unix: Use syscall.SysctlRaw in Sysctl
  * windows: run "go generate"
  * windows/registry: add code to access remote pc registry
  * x/sys/unix: added linux/mips{,le} support
* Tue Dec 13 2016 tboerger@suse.com
- Updated service definition
* Wed Aug 17 2016 tboerger@suse.com
- Added rpmlintrc for common golang linting
* Tue Aug 16 2016 tboerger@suse.com
- Applied latest changes for golang-packaging
* Fri Jul  8 2016 tboerger@suse.com
- Refactoed spec with a new unified layout
- Switched to disabled run service
* Sun Jul 12 2015 i@marguerite.su
- rename to golang-org-x-sys
- update version 0.0.0+git20150612.b4e2899
- use golang-packaging for packaging
* Mon Mar 23 2015 i@marguerite.su
- initial version 0.0.0+git20150320.8642817
